@@ -33,6 +33,9 @@
 #include <c++utilities/conversion/stringconversion.h>
 
 #include <KConfigGroup>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <KPluginMetaData>
+#endif
 
 #include <Plasma/Theme>
 #include <plasma/plasma_export.h>
@@ -48,6 +51,8 @@
 #include <QQmlEngine>
 #include <QStringBuilder>
 
+#include <iostream>
+
 using namespace std;
 using namespace Data;
 using namespace Plasma;
@@ -70,10 +75,11 @@ static inline QPalette paletteFromTheme(const Plasma::Theme &theme)
 #endif
 }
 
-SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    : Applet(parent, KPluginMetaData(), data)
+SyncthingApplet::SyncthingApplet(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Applet(parent, data, args)
 #else
+SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     : Applet(parent, data)
 #endif
     , m_faUrl(QStringLiteral("image://fa/"))
@@ -92,13 +98,22 @@ SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     , m_imageProvider(nullptr)
     , m_webViewDlg(nullptr)
     , m_notificationsDlg(nullptr)
-    , m_currentConnectionConfig(-1)
     , m_hasInternalErrors(false)
     , m_initialized(false)
     , m_showTabTexts(false)
     , m_showDownloads(false)
     , m_applyingSettingsForWizard(false)
 {
+    // load config
+    const auto &c = config();
+    if (c.readEntry<>("preferIconsFromTheme", false)) {
+        Data::setForkAwesomeThemeOverrides();
+    }
+    m_currentConnectionConfig = c.readEntry<int>("selectedConfig", 0);
+    m_defaultTab = c.readEntry<>("defaultTab", 0);
+    m_lastTab = c.readEntry<>("lastTab", 0);
+    m_defaultTab = m_defaultTab < 0 ? m_lastTab : m_defaultTab;
+
     // configure connection
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     m_connection.setPollingFlags(SyncthingConnection::PollingFlags::MainEvents | SyncthingConnection::PollingFlags::Errors);
@@ -119,6 +134,7 @@ SyncthingApplet::~SyncthingApplet()
 #ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     delete m_webViewDlg;
 #endif
+    config().writeEntry("lastTab", m_lastTab);
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     SyncthingService::setMainInstance(nullptr);
 #endif
@@ -143,6 +159,8 @@ void SyncthingApplet::init()
     setupCommonQtApplicationAttributes();
 
     Applet::init();
+    std::cerr << "Initializing " APP_NAME ", version " APP_VERSION "\n";
+    std::cerr << "Plugin ID: " << pluginMetaData().pluginId().toStdString() << '\n';
 
     // connect signals and slots
     connect(&m_notifier, &SyncthingNotifier::statusChanged, this, &SyncthingApplet::handleConnectionStatusChanged);
@@ -182,18 +200,11 @@ void SyncthingApplet::init()
     connect(&m_service, &SyncthingService::errorOccurred, this, &SyncthingApplet::handleSystemdServiceError);
 #endif
 
-    // load primary connection config
-    const auto &c = config();
-    m_currentConnectionConfig = c.readEntry<int>("selectedConfig", 0);
-
     // apply settings and connect according to settings
     const auto palette = paletteFromTheme(m_theme);
     setBrightColors(isPaletteDark(palette));
     m_iconManager.setPalette(palette);
     handleSettingsChanged();
-    if (c.readEntry<>("preferIconsFromTheme", false)) {
-        Data::setForkAwesomeThemeOverrides();
-    }
 
     // show wizard on first launch
     if (settings.firstLaunch || settings.fakeFirstLaunch) {
@@ -215,7 +226,8 @@ void SyncthingApplet::initEngine(QObject *object)
         return;
     }
     const auto color = m_theme.color(Plasma::Theme::TextColor, Plasma::Theme::NormalColorGroup);
-    m_imageProvider = new QtForkAwesome::QuickImageProvider(m_iconManager.forkAwesomeRenderer(), color);
+    m_imageProvider
+        = new QtForkAwesome::QuickImageProvider(QtForkAwesome::Renderer::global(), color); // using global renderer for system icons override
     connect(engine, &QObject::destroyed, this, &SyncthingApplet::handleImageProviderDestroyed); // engine has ownership over image provider
     engine->addImageProvider(QStringLiteral("fa"), m_imageProvider);
 }
@@ -379,6 +391,7 @@ void SyncthingApplet::triggerConnectButtonAction()
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 void SyncthingApplet::handleRelevantControlsChanged(bool visible, int tabIndex)
 {
+    m_lastTab = tabIndex;
     QtGui::handleRelevantControlsChanged(visible, tabIndex, m_connection);
 }
 #endif
@@ -735,6 +748,7 @@ void SyncthingApplet::applySettings(int changeConnectionIndex)
     setShowingTabTexts(config.readEntry<bool>("showTabTexts", false));
     setShowingDownloads(config.readEntry<bool>("showDownloads", false));
     m_iconManager.applySettings(&settings.icons.status, nullptr, settings.icons.usePaletteForStatus, false);
+    m_defaultTab = config.readEntry<>("defaultTab", 0);
 
     // restore selected states
     // note: The settings dialog writes this to the Plasmoid's config like the other settings. However, it
