@@ -308,6 +308,7 @@ bool restore()
             connectionSettings->autoConnect = settings.value(QStringLiteral("autoConnect"), connectionSettings->autoConnect).toBool();
             connectionSettings->pauseOnMeteredConnection
                 = settings.value(QStringLiteral("pauseOnMetered"), connectionSettings->pauseOnMeteredConnection).toBool();
+            connectionSettings->forceSuspend = settings.value(QStringLiteral("forceSuspend"), connectionSettings->forceSuspend).toBool();
             const auto statusComputionFlags = settings.value(QStringLiteral("statusComputionFlags"),
                 QVariant::fromValue(static_cast<UnderlyingFlagType>(connectionSettings->statusComputionFlags)));
             if (statusComputionFlags.canConvert<UnderlyingFlagType>()) {
@@ -358,6 +359,8 @@ bool restore()
     appearance.trayMenuSize = settings.value(QStringLiteral("trayMenuSize"), appearance.trayMenuSize).toSize();
     appearance.frameStyle = settings.value(QStringLiteral("frameStyle"), appearance.frameStyle).toInt();
     appearance.tabPosition = settings.value(QStringLiteral("tabPos"), appearance.tabPosition).toInt();
+    appearance.defaultTab = settings.value(QStringLiteral("defaultTab"), appearance.defaultTab).toInt();
+    appearance.lastTab = settings.value(QStringLiteral("lastTab"), appearance.lastTab).toInt();
     v.icons.status = StatusIconSettings(settings.value(QStringLiteral("statusIcons")).toString());
     v.icons.tray = StatusIconSettings(settings.value(QStringLiteral("trayIcons")).toString());
     v.icons.status.renderSize = settings.value(QStringLiteral("statusIconsRenderSize"), v.icons.status.renderSize).toSize();
@@ -471,6 +474,7 @@ bool save()
         settings.setValue(QStringLiteral("longPollingTimeout"), connectionSettings->longPollingTimeout);
         settings.setValue(QStringLiteral("autoConnect"), connectionSettings->autoConnect);
         settings.setValue(QStringLiteral("pauseOnMetered"), connectionSettings->pauseOnMeteredConnection);
+        settings.setValue(QStringLiteral("forceSuspend"), connectionSettings->forceSuspend);
         settings.setValue(QStringLiteral("statusComputionFlags"),
             QVariant::fromValue(static_cast<std::underlying_type_t<Data::SyncthingStatusComputionFlags>>(connectionSettings->statusComputionFlags)));
 #ifndef QT_NO_SSL
@@ -500,6 +504,8 @@ bool save()
     settings.setValue(QStringLiteral("trayMenuSize"), appearance.trayMenuSize);
     settings.setValue(QStringLiteral("frameStyle"), appearance.frameStyle);
     settings.setValue(QStringLiteral("tabPos"), appearance.tabPosition);
+    settings.setValue(QStringLiteral("defaultTab"), appearance.defaultTab);
+    settings.setValue(QStringLiteral("lastTab"), appearance.lastTab);
     settings.setValue(QStringLiteral("statusIcons"), v.icons.status.toString());
     settings.setValue(QStringLiteral("trayIcons"), v.icons.tray.toString());
     settings.setValue(QStringLiteral("statusIconsRenderSize"), v.icons.status.renderSize);
@@ -663,9 +669,10 @@ Systemd::ServiceStatus Systemd::status(SyncthingConnection &connection) const
 void Connection::addConfigFromWizard(const Data::SyncthingConfig &config)
 {
     // skip if settings basically don't change
-    const auto url = config.syncthingUrl();
+    const auto connectInfo = config.syncthingConnectInfo();
     const auto apiKey = config.guiApiKey.toUtf8();
-    if (url == primary.syncthingUrl && config.guiUser == primary.userName && config.guiApiKey == primary.apiKey) {
+    if (connectInfo.url == primary.syncthingUrl && connectInfo.path == primary.localPath && config.guiUser == primary.userName
+        && config.guiApiKey == primary.apiKey) {
         primary.authEnabled = false; // just disable auth to solely rely on the API key
         primary.autoConnect = true; // ensure the connection is actually established when applying
         return;
@@ -677,8 +684,8 @@ void Connection::addConfigFromWizard(const Data::SyncthingConfig &config)
         backup.label = QCoreApplication::translate("Settings::Connection", "Backup of %1 (created by wizard)").arg(backup.label);
     }
 
-    primary.syncthingUrl = url;
-    primary.localPath.clear();
+    primary.syncthingUrl = connectInfo.url;
+    primary.localPath = connectInfo.path;
     primary.userName = config.guiUser;
     primary.authEnabled = false;
     primary.password.clear();
